Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(691)

Unified Diff: remoting/client/ios/host_preferences.h

Issue 2555803002: Adding the iOS app and integration example with GlRenderer. (Closed)
Patch Set: Adjusting how gl_renderer draws layers and added a demo app for CRD iOS. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/client/ios/host_preferences.h
diff --git a/remoting/client/ios/host_preferences.h b/remoting/client/ios/host_preferences.h
index 6fb19a0a1276bd8d7299e935dd18a9506854e329..951bb796002576a87b2f1ae7153aeb4af4cd4743 100644
--- a/remoting/client/ios/host_preferences.h
+++ b/remoting/client/ios/host_preferences.h
@@ -7,6 +7,14 @@
#import <CoreData/CoreData.h>
+namespace remoting {
+namespace ios {
+
+NSError* writeHostPreferencesToKeychain(NSData*);
+NSData* readHostPreferencesFromKeychain();
+}
Sergey Ulanov 2016/12/19 23:50:22 // namespace ios
+}
+
// A HostPreferences contains details to negotiate and maintain a connection
// to a remote Chromoting host. This is an entity in a backing store.
@@ -17,12 +25,10 @@
@property(nonatomic, copy) NSString* pairId;
@property(nonatomic, copy) NSString* pairSecret;
-// Commit this record using the SSOKeychain
-// for SSOSigninManager's current identity.
-- (void)saveToSSOKeychain;
+// Commit this record using the Keychain for current identity.
+- (void)saveToKeychain;
-// Load a record from the SSOKeychain
-// for SSOSigninManager's current identity.
+// Load a record from the Keychain for current identity.
// If a record does not exist, return a new record with a blank secret.
+ (HostPreferences*)hostForId:(NSString*)hostId;

Powered by Google App Engine
This is Rietveld 408576698